Module loader

Module loader 

The loader module

Provides the Loader struct which is used to read data into DataTables.

Structs

LineSplitIter
Iterator to parse a line in a data file.
Loader
Loader struct
LoaderOptions
Options used to fine tune the file loading

Functions

load_file
Load the specified file to a DataTable.