Struct rusty_data::loader::Loader
[−]
[src]
pub struct Loader<'a> {
pub has_header: bool,
pub delimiter: char,
// some fields omitted
}Loader struct
Used to load and process data files into tables.
Fields
has_header: bool
True if there are headers present in the file
delimiter: char
The delimiter character